@@ -31,48 +31,78 @@
 #' @return Cross-references as data.frame
 #' @examples
 #'   \dontrun{
-#'   epmc_db("12368864", db = "uniprot", limit = 100)
+#'   epmc_db("12368864", db = "uniprot", limit = 150)
 #'   epmc_db("25249410", db = "embl")
 #'   epmc_db("14756321", db = "uniprot")
 #'   }
 #' @export
-epmc_db <- function(ext_id = NULL, data_src = "med", db = NULL,
-                            limit = 25, verbose = TRUE) {
+epmc_db <- function(ext_id = NULL,
+                    data_src = "med",
+                    db = NULL,
+                    limit = 100,
+                    verbose = TRUE) {
   if (is.null(ext_id))
     stop("Please provide a publication id")
   # build request
   if (is.null(db))
     stop("Please restrict reponse to a database")
   if (!toupper(db) %in% supported_db)
-    stop(paste0("Data source '", db, "' not supported. Try one of the
-                following sources: ", paste0(supported_db, collapse =", ")
-    ))
+    stop(
+      paste0(
+        "Data source '",
+        db,
+        "' not supported. Try one of the
+        following sources: ",
+        paste0(supported_db, collapse = ", ")
+      )
+    )
   if (!tolower(data_src) %in% supported_data_src)
-    stop(paste0("Data source '", data_src, "' not supported. Try one of the
-                following sources: ", paste0(supported_data_src, collapse =", ")
-    ))
+    stop(
+      paste0(
+        "Data source '",
+        data_src,
+        "' not supported. Try one of the
+        following sources: ",
+        paste0(supported_data_src, collapse = ", ")
+      )
+    )
   stopifnot(is.numeric(limit))
   stopifnot(is.logical(verbose))
   # build request
   req_method <- "databaseLinks"
   path = paste(rest_path(), data_src, ext_id, req_method, db,
-               "json", sep ="/")
+               "json", sep = "/")
   doc <- rebi_GET(path = path)
   hit_count <- doc$hitCount
-  if(hit_count == 0)
+  if (hit_count == 0)
     stop("Sorry, no links found")
-  paths <- make_path(hit_count = hit_count, limit = limit, ext_id = ext_id,
-                     data_src = data_src, req_method = req_method, type = db)
+  if (verbose == TRUE)
+    message(paste0(
+      hit_count,
+      " records found. Returning ",
+      ifelse(hit_count <= limit, hit_count, limit)
+    ))
+  paths <-
+    make_path(
+      hit_count = hit_count,
+      limit = limit,
+      ext_id = ext_id,
+      data_src = data_src,
+      req_method = req_method,
+      type = db
+    )
   out <- lapply(paths, function(x) {
-    if(verbose == TRUE)
-      message(paste0(hit_count, " records found. Returning ",
-                     ifelse(hit_count <= limit, hit_count, limit)))
     doc <- rebi_GET(path = x)
-    plyr::ldply(doc$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo,
-                data.frame, stringsAsFactors = FALSE, .id = NULL)
+    plyr::ldply(
+      doc$dbCrossReferenceList$dbCrossReference$dbCrossReferenceInfo,
+      data.frame,
+      stringsAsFactors = FALSE,
+      .id = NULL
+    )
   })
   #combine all into one
-  result <- jsonlite::rbind.pages(out)
+  result <- jsonlite::rbind.pages(out) %>%
+    dplyr::as_data_frame()
   # return
   attr(result, "hit_count") <- hit_count
   result
@@ -80,5 +110,12 @@ epmc_db <- function(ext_id = NULL, data_src = "med", db = NULL,
 
 
 # supported dbs
-supported_db <- c("CHEBI", "CHEMBL", "EMBL", "INTACT", "INTERPRO", "OMIM",
-                  "PDB", "UNIPROT")
+supported_db <-
+  c("CHEBI",
+    "CHEMBL",
+    "EMBL",
+    "INTACT",
+    "INTERPRO",
+    "OMIM",
+    "PDB",
+    "UNIPROT")
