@@ -15,12 +15,8 @@
 
 epmc_hits <- function(query = NULL, ...) {
   # check
-  if (is.null(query))
-    stop("No query provided")
+  query <- transform_query(query)
   path = paste0(rest_path(), "/search")
-  doc <- rebi_GET(path, query = list(query = query, format = "json", ...))
-  hit_count <- doc$hitCount
-  if(hit_count == 0)
-      stop("nothing found, please check your query")
-  hit_count
+  doc <- rebi_GET(path, query = list(query = query, format = "json", resulttype = "idlist"))
+  doc$hitCount
 }
